@@ -1,10 +1,6 @@
 # Copyright 2021 Variscite LTD
 # SPDX-License-Identifier: BSD-3-Clause
 
-import os
-
-# Local Files
-CACHEDIR = os.path.join(os.environ['HOME'], ".cache", "pyvar")
-
 CLASSIFICATION = "classification"
 DETECTION = "detection"
+SEGMENTATION = "segmentation"
